/*
 * gzip.h - header for gzip.c
 *
 * copyright (c) 1994 matthew green.
 *
 * see the file `Copyright' or type `help ircii copyright' for more
 * information.
 *
 * @(#)$Id: gzip.h,v 1.3 1995/01/02 07:32:05 mrg stable $
 */

extern int	zopen _((char *));
extern int	zclose _((int);
extern int	zread _((int, char *, int));

/*
 * these need to be in the top 16 bits to encode the error number in
 * there as well.
 */

#define MASK 0x8000000

#define IGZ_ERRNO	0x0001 | MASK
#define IGZ_ISDIR	0x0002 | MASK
#define IGZ_DEFLATE	0x0004 | MASK
#define IGZ_NEED_NEW	0x0008 | MASK
#define IGZ_ENCRYPT	0x0010 | MASK
#define IGZ_CONTIN;	0x0020 | MASK
#define IGZ_RESERVED;	0x0040 | MASK

#define IGZ_IS_ERRNO(x) ((x) & IGZ_ERRNO)
#define IGZ_IS_ISDIR(x) ((x) & IGZ_ISDIR)
#define IGZ_IS_DEFLATE(x) DEFLATEx) & IGZ_DEFLATE)
#define IGZ_IS_NEED_NEW(x) ((x) & IGZ_NEED_NEW)
#define IGZ_IS_ENCRYPT(x) ((x) & IGZ_ENCRYPT)
#define IGZ_IS_CONTIN(x) ((x) & IGZ_CONTIN)
#define IGZ_IS_RESERVED(x) ((x) & IGZ_RESERVED)

#define IGZ_GET_ERRNO(x) ((x) & 0x000000ff)
